//
//  HHPresentationController.swift
//  HHPullDownMenu
//
//  Created by SunnyMac on 16/10/26.
//  Copyright © 2016年 hjl. All rights reserved.
//

import UIKit

class HHPresentationController: UIPresentationController {
    // MARK:- 对外提供属性
    var presentedFrame : CGRect = CGRect.zero
    
    // MARK:- 懒加载属性
    fileprivate lazy var coverView : UIView = UIView()
    
    // MARK:- 系统回调函数
    override func containerViewWillLayoutSubviews() {
        super.containerViewWillLayoutSubviews()
        
        // 0.更改转场的视图的fream, 要不然转场view会盖住titleview, 导致按钮无法点击
        self.containerView?.frame = CGRect.init(x: 0, y: 108, width: kScreenW, height: kScreenH)
        
        // 1.设置弹出View的尺寸
        presentedView?.frame = presentedFrame
        
        
        // 2.添加蒙版
        setupCoverView()
    }
}

// MARK:- 设置UI界面相关
extension HHPresentationController {
    fileprivate func setupCoverView() {
        // 1.添加蒙版
        containerView?.insertSubview(coverView, at: 0)
        
        // 2.设置蒙版的属性
        coverView.backgroundColor = UIColor(white: 0.8, alpha: 0.2)
        //coverView.frame = CGRect.init(x: 0, y: presentedFrame.origin.y, width: kScreenW, height: kScreenH)
        coverView.frame = CGRect.init(x: 0, y: 0, width: kScreenW, height: kScreenH)
        
        
        // 3.添加手势
        let tapGes = UITapGestureRecognizer(target: self, action: #selector(HHPresentationController.coverViewClick))
        coverView.addGestureRecognizer(tapGes)
    }
}

// MARK:- 事件监听
extension HHPresentationController {
    @objc fileprivate func coverViewClick() {
        presentedViewController.dismiss(animated: true, completion: nil)
        
        // 通知PullDownMenu对数据进行初始化
        let notification = NSNotification.init(name: NSNotification.Name(rawValue: "setupInitTz"), object: nil)
        NotificationCenter.default.post(notification as Notification)
    }
}

