//
//  HHPullDownMenu.swift
//  HHPullDownMenu
//
//  Created by SunnyMac on 16/10/25.
//  Copyright © 2016年 hjl. All rights reserved.
//

import UIKit

class HHPullDownMenu: UIView {

    fileprivate lazy var hhAnimation : HHAnimation = HHAnimation {[weak self] (presented) -> () in}
    
    // 2.创建弹出控制器的来源控制器
    weak var sourceVc = UIViewController()

    
    // MARK:- 定义属性
    fileprivate var childVcs : [UIViewController]
    
    fileprivate var titles : [String]
    
    fileprivate var buttons : [UIButton] = [UIButton]()
    
    fileprivate var oldBtnIndex : Int = 999
    
    var isShow: Bool = false

    init(frame: CGRect,  titles: [String], sourceVc: UIViewController, childVcs : [UIViewController]) {
        
        self.sourceVc = sourceVc
        
        self.titles = titles
        
        self.childVcs = childVcs
        
        super.init(frame: frame)
        
        // 设置UI
        setupUI()
        
        // 添加title的通知
        NotificationCenter.default.addObserver(self, selector: #selector(HHPullDownMenu.setupInit), name: NSNotification.Name(rawValue: "setupInitTz"), object: nil)
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    func setupUI() {
        backgroundColor = UIColor.white
    }
    
    
    
    
    // 布局子控件
    override func layoutSubviews() {
        
        super.layoutSubviews()
        
        let BottomLine = UIView()
        BottomLine.frame = CGRect.init(x: 0, y: self.bounds.size.height - 1, width: self.bounds.size.width, height: 1)
        BottomLine.backgroundColor = UIColor.init(red: 100/255, green: 100/255, blue: 100/255, alpha: 0.3)
        self.addSubview(BottomLine)

        
        let count = self.titles.count
        let btnY : CGFloat = 0
        let btnW : CGFloat = self.bounds.size.width / CGFloat(count)
        let btnH : CGFloat = self.bounds.size.height - 1
        
        for index in 0 ..< count {
            
            let button = UIButton()
            
            button.frame = CGRect.init(x: btnW * CGFloat(index), y: btnY, width: btnW, height: btnH)

            button.addTarget(self, action: #selector(btnClick), for: .touchUpInside)
            
            button.setTitle(titles[index], for: .normal)
            
            button.setTitleColor(UIColor.black, for: .normal)
            button.setTitleColor(UIColor.blue, for: .selected)
            
            button.isSelected = false
            
            button.tag = index
            
            self.addSubview(button)
            self.buttons.append(button)
            
            if index < count - 1 {
                let separateLine = UIView()
                separateLine.frame = CGRect.init(x: btnW * CGFloat(index + 1) - 1, y: 5, width: 1, height: btnH - 10)
                separateLine.backgroundColor = UIColor.init(red: 100/255, green: 100/255, blue: 100/255, alpha: 0.3)
                self.addSubview(separateLine)
            }
        }
    }
    
    func btnClick(btn : UIButton)  {
        // 0.如果选中的还是上一次那个按钮, 则直接跳出
        if btn.tag == oldBtnIndex {
            return
        }
        
        // 1.如果有显示的, 那么先隐藏
        if isShow == true {
            sourceVc!.dismiss(animated: true, completion: nil)
        }
        
        // 2.点击的按钮,设置为选中状态
        self.buttons[btn.tag].isSelected = true
        
        // 3.取消上一次按钮的选中状态
        if oldBtnIndex != 999 {
            self.buttons[oldBtnIndex].isSelected = false
        }
        
        // 4.创建弹出的控制器
        let popoverVc : BaseViewController = self.childVcs[btn.tag] as! BaseViewController
        
        // 5.记录选中的为哪一列
        popoverVc.listNumber = btn.tag
        
        // 6.设置控制器的modal样式
        popoverVc.modalPresentationStyle = .custom
        
        // 7.设置转场的代理
        popoverVc.transitioningDelegate = hhAnimation
        
        let presentedX = 0
        let presentedY = 0
        let presentedW = kScreenW
        
        // 如果数据过多, 则最大为 : kscreenH - 64(nav) - 44(title) - 50(tab) - 30(美观)
        var presentedH = popoverVc.data.count * 44
        if presentedH > Int(kScreenH) - 190 {
            presentedH = Int(kScreenH) - 190
        }
 
        hhAnimation.presentedFrame = CGRect.init(x: presentedX, y: presentedY, width: Int(presentedW), height: presentedH)
        
        // 8.弹出控制器
        sourceVc!.present(popoverVc, animated: true, completion: nil)
        
        // 9.显示当前有页面显示
        isShow = true
        
        // 10.保存上一次的btn的tag
        oldBtnIndex = btn.tag
    }
}

extension HHPullDownMenu {
    @objc func setupInit() {
        // 取消按钮的选中状态
        buttons[oldBtnIndex].isSelected = false
        // oldBtnIndex设置为初始值
        oldBtnIndex = 999
    }
}





